..
      Copyright 2014 IBM Corp.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

.. _tags:

=====
 Tags
=====

A "tag" is a label that can be added to a CADF Event Record to qualify or
categorize an event.

Tags provide a powerful mechanism for adding domain-specific identifiers and
classifications to CADF Event Records that can be referenced by the CADF Query
Interface. This allows customers to construct custom reports or views on the
event data held by a provider for a specific domain of interest. A CADF Event
Record can have multiple tags that enable cross-domain analysis.